(function(wp) {
    var el = wp.element.createElement;
    var InspectorControls = wp.editor.InspectorControls;
    var RichText = wp.editor.RichText;
    var Fragment = wp.element.Fragment;
    var MediaUpload = wp.editor.MediaUpload;
    var TextControl = wp.components.TextControl;
    var RangeControl = wp.components.RangeControl;
    var CheckboxControl = wp.components.ToggleControl;
    var SelectControl = wp.components.SelectControl;
    var ButtonGroup = wp.components.ButtonGroup;
    var Button = wp.components.Button;
    var ColorPalette = wp.components.ColorPalette;
	var ServerSideRender = wp.components.ServerSideRender;
    var __ = wp.i18n.__;

	var categorySelections = [];
	var allCategories = wp.apiFetch({path: "/wp/v2/contact_group"}).then(posts => {
		categorySelections.push({label: __('Select a category', 'cosmic-blocks'), value: 0});
		$.each( posts, function( key, val ) {
			categorySelections.push({label: val.name, value: val.id});
		});
		return categorySelections;
	});

    wp.blocks.registerBlockType('cwp/contacts-list', {
        title: __('Contacts List', 'cosmic-blocks'),
		keywords: [
			'contacts list',
			__('persons list', 'cosmic-blocks')
		],
        icon: {
			background: "#16A3FF",
			foreground: "#FFFFFF",
			src: "admin-users"
		},
        category: 'cwp-blocks',
        attributes: {
			preview: {
				type: 'boolean',
				default: false
			},
			blockID: {
				type: 'string',
				default: ''
			},
			columns: {
                type: "number",
                default: 1
            },
            container: {
                type: "string",
                default: 'cwp-full-width-wide-container'
            },
            backgroundType: {
                type: "string",
                default: 'color'
            },
			backgroundTextColor: {
				type: "string",
                default: ''
			},
            solidColor: {
                type: "string",
                default: ''
            },
            gradient: {
                type: "string"
            },
            backgroundMediaID: {
                type: "number"
            },
            backgroundMediaURL: {
                type: "string"
            },
            animationStyle: {
                type: "string"
            },
            animationDelay: {
                type: "number",
                default: 10
            },
            threshold: {
                type: "number",
                default: 40
            },
			paddingBeforeIntro: {
				type: 'number',
				default: 50
			},
			paddingAfterIntro: {
				type: 'number',
				default: 50
			},
			paddingAfterItems: {
				type: 'number',
				default: 50
			},
			introsection: {
                type: 'string',
                introdefault: 'empty'
            },
            introtitle: {
                type: "string",
                default: ''
            },
            introsubtitle: {
                type: "string",
                default: ''
            },
            introduction: {
                type: "string",
                default: ''
            },
			boxradius: {
                type: "number",
                default: 0
            },
			boxradiusfix: {
				type: 'boolean',
				default: false
			},
            boxpadding: {
                type: "number",
                default: 0
            },
			boxpaddingfix: {
				type: 'boolean',
				default: false
			},
			selectedCategory: {
				type: "string",
                default: ""
			},
			postsPerPage: {
                type: "string",
                default: '25'
            },
			filter: {
                type: "string",
                default: 'all'
            },
			order: {
                type: "string",
                default: 'cosmic_campaigns_contact_last_name'
            },
			showImage: {
                type: "boolean",
                default: true
            },
			showSalutation: {
                type: "boolean",
                default: false
            },
			showSuffix: {
                type: "boolean",
                default: false
            },
            showName: {
                type: "boolean",
                default: true
            },
            showFunction: {
                type: "boolean",
                default: true
            },
            showStreetAndNumber: {
                type: "boolean",
                default: false
            },
            showZipAndPlace: {
                type: "boolean",
                default: true
            },
			showCountry: {
                type: "boolean",
                default: false
            },
            showEmail: {
                type: "boolean",
                default: false
            },
			showMobile: {
                type: "boolean",
                default: false
            },
			showPhonePrivate: {
                type: "boolean",
                default: false
            },
			showPhoneWork: {
                type: "boolean",
                default: false
            },
			showWebsiteAndSocialMedia: {
                type: "boolean",
                default: false
            },
			showWebsiteAndSocialMediaStyle: {
                type: "string",
                default: "cwp-button cwp-button-white"
            },
			showPagination: {
                type: "boolean",
                default: true
            },
			paginationStyle: {
                type: "string",
                default: "cwp-pagination cwp-pagination-secondary"
            },
            textcolor: {
                type: "string",
                default: ""
            },
            color: {
                type: "string",
                default: ""
            }
        },
        getEditWrapperProps({
            container
        }) {
            if ('cwp-full-width-wide-container' === container || 'cwp-full-width-small-container' === container || 'cwp-same-width-full-container' === container) {
                return {
                    'data-align': 'full'
                };
            } else if ('cwp-same-width-wide-container' === container) {
                return {
                    'data-align': 'wide'
                };
            }
        },
        edit: function(props) {
			var attributes = props.attributes;

			// override default params for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{
				attributes.paddingBeforeIntro = -1;
				attributes.paddingAfterIntro = -1;
				attributes.paddingAfterItems = -1;
				attributes.boxradius = -1;
				attributes.boxradiusfix = true;
				attributes.boxpadding = -1;
				attributes.boxpaddingfix = true;
				attributes.container = 'cwp-full-width-small-container';
			}
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}

			var solidColorPreset = el(ColorPalette, {
				value: attributes.solidColor,
				onChange: function(e) {
					props.setAttributes({
						solidColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#00d1b2",
					name: "teal"
				}, {
					color: "#3373dc",
					name: "royal blue"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var backgroundTextColorPreset = el(ColorPalette, {
				value: attributes.backgroundTextColor,
				onChange: function(e) {
					props.setAttributes({
						backgroundTextColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#333333",
					name: "dark"
				}, {
					color: "#000000",
					name: "black"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var gradientPreset = el(SelectControl, {
				label: __('Gradients', 'cosmic-blocks'),
				options: gradient_options.map(function(e) {
					return {
						value: e.colors,
						label: e.name
					};
				}),
				value: attributes.gradient,
				onChange: function(e) {
					props.setAttributes({
						gradient: e
					});
				}
			});
			var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var block_text_style = function() {
				var s = {};
				if(attributes.textcolor !== '' && attributes.textcolor !== undefined) {
					s = {
						color: attributes.textcolor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};
			
            return [
                el(
                    Fragment,
                    null,
					el(InspectorControls, {
                            key: 'inspector'
                        }, // Display the block options in the inspector panel.
						el(wp.components.PanelBody, {
								title: __('Intro', 'cosmic-blocks'),
								className: 'cwp-inspector-intro',
								initialOpen: false
							},
							el(SelectControl, {
								label: __('Enable/disable', 'cosmic-blocks'),
								value: attributes.introsection,
								options: [{
										label: __('Disabled', 'cosmic-blocks'),
										value: 'disabled'
									},
									{
										label: __('Enabled', 'cosmic-blocks'),
										value: 'enabled'
									}
								],
								onChange: function onChange(value) {
									props.setAttributes({
										introsection: value
									});
								}
							}),
							attributes.introsection === 'enabled' ? el('p', {}, __('Intro text color', 'cosmic-blocks')) : '',
							attributes.introsection === 'enabled' ? backgroundTextColorPreset : '',
							attributes.introsection === 'enabled' ? el(RangeControl, {
								label: __('Padding after intro text', 'cosmic-blocks'),
								value: attributes.paddingAfterIntro,
								allowReset: false,
								initialPosition: 50,
								onChange: function(e) {
									return props.setAttributes({
										paddingAfterIntro: e
									});
								},
								min: -1,
								max: 200
							}) : '',
						),
                        el(wp.components.PanelBody, {
                                title: __('Layout', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: false
							},
                            el(SelectControl, {
                                label: __('Container width', 'cosmic-blocks'),
                                value: attributes.container,
                                options: container_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    props.setAttributes({
                                        container: e
                                    });
                                }
                            }),
                            el(RangeControl, {
                                label: __('Padding top', 'cosmic-blocks'),
                                value: attributes.paddingBeforeIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingBeforeIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el(RangeControl, {
                                label: __('Padding bottom', 'cosmic-blocks'),
                                value: attributes.paddingAfterItems,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingAfterItems: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el('p', {
                                className: 'cwp-custom-label'
                            }, __('Background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.backgroundType === e.value,
                                        "aria-pressed": attributes.backgroundType === e.value,
                                        onClick: function() {
                                            return props.setAttributes({
                                                backgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.backgroundType && solidColorPreset,
                            "gradient" === attributes.backgroundType && gradientPreset,
                            "image" === attributes.backgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            backgroundMediaURL: media.url,
                                            backgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.backgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.backgroundMediaID ? el("img", {
                                            src: attributes.backgroundMediaURL
                                        }) : __('Set background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.backgroundType && attributes.backgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, __('Click the image to edit or update', 'cosmic-blocks')), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        backgroundMediaURL: void 0,
                                        backgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
                            el(TextControl, {
                                label: __('Block ID', 'cosmic-blocks'),
                                value: attributes.blockID,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        blockID: e
                                    });
                                }
                            }),
						),
						el(wp.components.PanelBody, {
                                title: __('Items', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: true
                            },
							el('div', {
									className: ''
								},
								el(SelectControl,
									{
										label: __('by group'),
										options: categorySelections,
										value: attributes.selectedCategory,
										onChange: function(e) {
											return props.setAttributes({
												selectedCategory: e
											});
										}
									}
								)
							),
							el('div', {
									className: ''
								},
								el(TextControl, {
									type: 'number',
									label: __('Posts per page', 'cosmic-blocks'),
									value: attributes.postsPerPage,
									onChange: function(e) {
										return props.setAttributes({
											postsPerPage: e
										});
									}
								}),
							),
							el('div', {
									className: ''
								},
								el(SelectControl, {
									label: __('Contacts', 'cosmic-blocks'),
									value: attributes.filter,
									options: [
										{
											label: __('All', 'cosmic-blocks'),
											value: 'all'
										},
										{
											label: __('Committee', 'cosmic-blocks'),
											value: 'committee'
										},
										{
											label: __('Petition', 'cosmic-blocks'),
											value: 'petition'
										}
									],
									onChange: function(e) {
										props.setAttributes({
											filter: e
										});
									}
								})
							),
							el('div', {
									className: ''
								},
								el(SelectControl, {
									label: __('Order', 'cosmic-blocks'),
									value: attributes.order,
									options: [
										{
											label: __('by last name', 'cosmic-blocks'),
											value: 'cosmic_campaigns_contact_last_name'
										},
										{
											label: __('by first name', 'cosmic-blocks'),
											value: 'cosmic_campaigns_contact_first_name'
										},
										{
											label: __('by date', 'cosmic-blocks'),
											value: 'date'
										}
									],
									onChange: function(e) {
										props.setAttributes({
											order: e
										});
									}
								})
							),
							el('p', {
								style: block_text_style()
							}, __('Show or hide items', 'cosmic-blocks')),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Image', 'cosmic-blocks'),
									checked: attributes.showImage,
									onChange: function(e) {
										return props.setAttributes({
											showImage: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Salutation', 'cosmic-blocks'),
									checked: attributes.showSalutation,
									onChange: function(e) {
										return props.setAttributes({
											showSalutation: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Suffix', 'cosmic-blocks'),
									checked: attributes.showSuffix,
									onChange: function(e) {
										return props.setAttributes({
											showSuffix: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('First and Lastname', 'cosmic-blocks'),
									checked: attributes.showName,
									onChange: function(e) {
										return props.setAttributes({
											showName: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Function', 'cosmic-blocks'),
									checked: attributes.showFunction,
									onChange: function(e) {
										return props.setAttributes({
											showFunction: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Street and number', 'cosmic-blocks'),
									checked: attributes.showStreetAndNumber,
									onChange: function(e) {
										return props.setAttributes({
											showStreetAndNumber: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Zip and place', 'cosmic-blocks'),
									checked: attributes.showZipAndPlace,
									onChange: function(e) {
										return props.setAttributes({
											showZipAndPlace: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Country', 'cosmic-blocks'),
									checked: attributes.showCountry,
									onChange: function(e) {
										return props.setAttributes({
											showCountry: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Email', 'cosmic-blocks'),
									checked: attributes.showEmail,
									onChange: function(e) {
										return props.setAttributes({
											showEmail: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Mobile', 'cosmic-blocks'),
									checked: attributes.showMobile,
									onChange: function(e) {
										return props.setAttributes({
											showMobile: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Phone (private)', 'cosmic-blocks'),
									checked: attributes.showPhonePrivate,
									onChange: function(e) {
										return props.setAttributes({
											showPhonePrivate: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Phone (work)', 'cosmic-blocks'),
									checked: attributes.showPhoneWork,
									onChange: function(e) {
										return props.setAttributes({
											showPhoneWork: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Website and social media', 'cosmic-blocks'),
									checked: attributes.showWebsiteAndSocialMedia,
									onChange: function(e) {
										return props.setAttributes({
											showWebsiteAndSocialMedia: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: __('Pagination', 'cosmic-blocks'),
									checked: attributes.showPagination,
									onChange: function(e) {
										return props.setAttributes({
											showPagination: e
										});
									}
								}),
							),
							attributes.showPagination === true ? el('hr') : '',
							attributes.showPagination === true ? el(SelectControl, {
								label: __('Pagination style', 'cosmic-blocks'),
								value: attributes.paginationStyle,
								options: pagination_options.map(function(e) {
									return {
										value: e.value,
										label: e.label
									}
								}),
								onChange: function onChange(value) {
									return props.setAttributes({
										paginationStyle: value
									});
								}
							}) : '',
							attributes.showWebsiteAndSocialMedia === true ? el('hr') : '',
							attributes.showWebsiteAndSocialMedia === true ? el(SelectControl, {
								label: __('Social buttons style', 'cosmic-blocks'),
								value: attributes.showWebsiteAndSocialMediaStyle,
								options: button_options.map(function(e) {
									return {
										value: e.value,
										label: e.label
									};
								}),
								onChange: function onChange(value) {
									return props.setAttributes({
										showWebsiteAndSocialMediaStyle: value
									});
								}
							}) : '',
							el('hr'),
							el(RangeControl, {
								label: __('Items border radius', 'cosmic-blocks'),
								value: attributes.boxradius,
								onChange: function(e) {
									return props.setAttributes({
										boxradius: e,
										boxradiusfix: true
									});
								},
								min: -1,
								max: 50
							}),
							el(RangeControl, {
								label: __('Items padding', 'cosmic-blocks'),
								value: attributes.boxpadding,
								onChange: function(e) {
									return props.setAttributes({
										boxpadding: e,
										boxpaddingfix: true
									});
								},
								min: -1,
								max: 50
							})
						),
						el(wp.components.PanelBody, {
                                title: __('Animation', 'cosmic-blocks'),
                                className: 'cwp-inspector-animation',
                                initialOpen: false
                            },
                            el(SelectControl, {
								label: __('Animation', 'cosmic-blocks'),
                                value: attributes.animationStyle,
                                options: animation_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationStyle: e
                                    });
                                }
                            }),
                            el(TextControl, {
								label: __('Animation Delay', 'cosmic-blocks'),
                                value: attributes.animationDelay,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationDelay: e
                                    });
                                },
                                help: __('Enter in milliseconds', 'cosmic-blocks')
                            }),
                            el(RangeControl, {
                                beforeIcon: 'arrow-left-alt2',
                                afterIcon: 'arrow-right-alt2',
                                label: __('Threshold', 'cosmic-blocks'),
                                value: attributes.threshold,
								allowReset: false,
								initialPosition: 40,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        threshold: e
                                    });
                                },
                                min: 0,
                                max: 100
                            }),
                        )
                    ),
					el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-backend-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
							style: back_style()
                        },
						el('div', {
                                className: 'cwp-common-main-wrap-inner' + (attributes.animationStyle !== '' && attributes.animationStyle !== undefined ? ' animated ' + attributes.animationStyle : ''),
								style: box_padding()
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
									sstyle: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'h3',
                                            placeholder: __('Title', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introtitle,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-subtitle'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Subtitle', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introsubtitle,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introsubtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Introduction', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introduction,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introduction: e
                                                });
                                            }
                                        }),
                                    ),
                                )
                            ) : '',
                            el('div', {
                                    className: 'cwp-main-wrapper cwp-1-column'
                                },
								el('div', {
										className: 'cwp-inner-wrap'
									},
									el('div', {
                                            className: 'cwp-meta-options'
                                        },
                                        el('div', {
                                                className: 'cwp-element-bgcolor-main'
                                            },
                                            el('div', {
                                                    className: 'cwp-drag-item cwp-option-bgcolor'
                                                },
                                                el('i', {
                                                    className: 'fa fa-paint-brush'
                                                }),
                                                el(ColorPalette, {
                                                    value: attributes.color,
                                                    onChange: function(e) {
                                                        return props.setAttributes({
                                                            color: e
                                                        });
                                                    }
                                                })
                                            )
                                        ),
                                        el('div', {
                                                className: 'cwp-element-textcolor-main'
                                            },
                                            el('div', {
                                                    className: 'cwp-drag-item cwp-option-textcolor'
                                                },
                                                el('i', {
                                                    className: 'fa fa-font'
                                                }),
                                                el(ColorPalette, {
                                                    value: attributes.textcolor,
                                                    onChange: function(e) {
                                                        return props.setAttributes({
                                                            textcolor: e
                                                        });
                                                    }
                                                })

                                            ),
                                        ),
                                    ),
									el('div', {
											className: 'cwp-server-side-render'
										},
										el(ServerSideRender, {
											block: "cwp/contacts-list",
											attributes: {
												preview: true,
												blockID: attributes.blockID,
												columns: attributes.columns,
												container: attributes.container,
												backgroundType: attributes.backgroundType,
												backgroundTextColor: attributes.backgroundTextColor,
												solidColor: attributes.solidColor,
												gradient: attributes.gradient,
												backgroundMediaID: attributes.backgroundMediaID,
												backgroundMediaURL: attributes.backgroundMediaURL,
												animationStyle: attributes.animationStyle,
												animationDelay: attributes.animationDelay,
												threshold: attributes.threshold,
												paddingBeforeIntro: attributes.paddingBeforeIntro,
												paddingAfterIntro: attributes.paddingAfterIntro,
												paddingAfterItems: attributes.paddingAfterItems,
												introtitle: attributes.introtitle,
												introsection: attributes.introsection,
												introsubtitle: attributes.introsubtitle,
												introduction: attributes.introduction,
												boxradius: attributes.boxradius,
												boxradiusfix: attributes.boxradiusfix,
												boxpadding: attributes.boxpadding,
												boxpaddingfix: attributes.boxpaddingfix,
												selectedCategory: attributes.selectedCategory,
												postsPerPage: attributes.postsPerPage,
												filter: attributes.filter,
												order: attributes.order,
												showImage: attributes.showImage,
												showSalutation: attributes.showSalutation,
												showSuffix: attributes.showSuffix,
												showName: attributes.showName,
												showFunction: attributes.showFunction,
												showStreetAndNumber: attributes.showStreetAndNumber,
												showZipAndPlace: attributes.showZipAndPlace,
												showCountry: attributes.showCountry,
												showEmail: attributes.showEmail,
												showMobile: attributes.showMobile,
												showPhonePrivate: attributes.showPhonePrivate,
												showPhoneWork: attributes.showPhoneWork,
												showWebsiteAndSocialMedia: attributes.showWebsiteAndSocialMedia,
												showWebsiteAndSocialMediaStyle: attributes.showWebsiteAndSocialMediaStyle,
												showPagination: attributes.showPagination,
												paginationStyle: attributes.paginationStyle,
												textcolor: attributes.textcolor,
												color: attributes.color
											}
										})
									)
								)
                            )
                        )
                    ),
			
					/** Front view **/
					el('div', {
                            id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-front-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap-inner',
                                style: box_padding(),
                                "data-scroll-class": attributes.animationStyle,
                                "data-scroll-delay": attributes.animationDelay,
                                "data-scroll-threshold": attributes.threshold
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
                                    style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('h3', {
                                            style: back_text_style()
                                        },
                                        (attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
                                            RichText.Content, {
                                                tagName: '',
                                                value: attributes.introtitle
                                            }
                                        ) : '',
                                        (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
                                            RichText.Content, {
                                                tagName: 'span',
                                                value: attributes.introsubtitle
                                            }
                                        ) : '',
                                    ),
                                ) : '',
                                (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(
                                            RichText.Content, {
                                                tagName: 'p',
                                                value: attributes.introduction,
                                                style: back_text_style()
                                            }
                                        ),
                                    ),
                                ) : '',
                            ) : '',
							el(ServerSideRender, {
								block: "cwp/contacts-list",
								attributes: {
									preview: true,
									blockID: attributes.blockID,
									columns: attributes.columns,
									container: attributes.container,
									backgroundType: attributes.backgroundType,
									backgroundTextColor: attributes.backgroundTextColor,
									solidColor: attributes.solidColor,
									gradient: attributes.gradient,
									backgroundMediaID: attributes.backgroundMediaID,
									backgroundMediaURL: attributes.backgroundMediaURL,
									animationStyle: attributes.animationStyle,
									animationDelay: attributes.animationDelay,
									threshold: attributes.threshold,
									paddingBeforeIntro: attributes.paddingBeforeIntro,
									paddingAfterIntro: attributes.paddingAfterIntro,
									paddingAfterItems: attributes.paddingAfterItems,
									introsection: attributes.introsection,
									introtitle: attributes.introtitle,
									introsubtitle: attributes.introsubtitle,
									introduction: attributes.introduction,
									boxradius: attributes.boxradius,
									boxradiusfix: attributes.boxradiusfix,
									boxpadding: attributes.boxpadding,
									boxpaddingfix: attributes.boxpaddingfix,
									selectedCategory: attributes.selectedCategory,
									postsPerPage: attributes.postsPerPage,
									filter: attributes.filter,
									order: attributes.order,
									showImage: attributes.showImage,
									showSalutation: attributes.showSalutation,
									showSuffix: attributes.showSuffix,
									showName: attributes.showName,
									showFunction: attributes.showFunction,
									showStreetAndNumber: attributes.showStreetAndNumber,
									showZipAndPlace: attributes.showZipAndPlace,
									showCountry: attributes.showCountry,
									showEmail: attributes.showEmail,
									showMobile: attributes.showMobile,
									showPhonePrivate: attributes.showPhonePrivate,
									showPhoneWork: attributes.showPhoneWork,
									showWebsiteAndSocialMedia: attributes.showWebsiteAndSocialMedia,
									showWebsiteAndSocialMediaStyle: attributes.showWebsiteAndSocialMediaStyle,
									showPagination: attributes.showPagination,
									paginationStyle: attributes.paginationStyle,
									textcolor: attributes.textcolor,
									color: attributes.color
								}
							})
                        )
                    )
                )
            ];
        },
        save: function() {
			// Rendering in PHP
			return null;
        }
    });
})(
    window.wp
);