(function(wp) {
    var el = wp.element.createElement;
    var InspectorControls = wp.editor.InspectorControls;
    var RichText = wp.editor.RichText;
    var Fragment = wp.element.Fragment;
    var MediaUpload = wp.editor.MediaUpload;
    var TextControl = wp.components.TextControl;
    var RangeControl = wp.components.RangeControl;
    var CheckboxControl = wp.components.ToggleControl;
    var SelectControl = wp.components.SelectControl;
    var ButtonGroup = wp.components.ButtonGroup;
    var Button = wp.components.Button;
    var ColorPalette = wp.components.ColorPalette;
	var ServerSideRender = wp.components.ServerSideRender;
    var __ = wp.i18n.__;

    wp.blocks.registerBlockType('cwp/social-share', {
        title: __('Social Share', 'cosmic-blocks'),
		keywords: [
			'social share',
			__('social media buttons', 'cosmic-blocks')
		],
        icon: {
			background: "#16A3FF",
			foreground: "#FFFFFF",
			src: "share"
		},
        category: 'cwp-blocks',
        attributes: {
			preview: {
				type: 'boolean',
				default: false
			},
			blockID: {
				type: 'string',
				default: ''
			},
			columns: {
                type: "number",
                default: 1
            },
			buttonStyle: {
                type: "string",
                default: 'cwp-button cwp-button-white'
            },
			buttonType: {
                type: "string",
                default: 'text_icon'
            },
			positionClass: {
                type: "string",
                default: 'cwp-all-left'
            },
            container: {
                type: "string",
                default: 'cwp-full-width-wide-container'
            },
            backgroundType: {
                type: "string",
                default: 'color'
            },
			backgroundTextColor: {
				type: "string",
                default: ''
			},
            solidColor: {
                type: "string",
                default: ''
            },
            gradient: {
                type: "string"
            },
            backgroundMediaID: {
                type: "number"
            },
            backgroundMediaURL: {
                type: "string"
            },
            animationStyle: {
                type: "string"
            },
            animationDelay: {
                type: "number",
                default: 10
            },
            threshold: {
                type: "number",
                default: 40
            },
			paddingBeforeIntro: {
				type: 'number',
				default: 50
			},
			paddingAfterIntro: {
				type: 'number',
				default: 50
			},
			paddingAfterItems: {
				type: 'number',
				default: 50
			},
			introsection: {
                type: 'string',
                introdefault: 'empty'
            },
            introtitle: {
                type: "string",
                default: ''
            },
            introsubtitle: {
                type: "string",
                default: ''
            },
            introduction: {
                type: "string",
                default: ''
            },
			boxradius: {
                type: "number",
                default: 0
            },
			boxradiusfix: {
				type: 'boolean',
				default: false
			},
            boxpadding: {
                type: "number",
                default: 0
            },
			boxpaddingfix: {
				type: 'boolean',
				default: false
			},
            facebook: {
                type: "boolean",
                default: true
            },
            twitter: {
                type: "boolean",
                default: true
            },
            linkedin: {
                type: "boolean",
                default: true
            },
            whatsapp: {
                type: "boolean",
                default: true
            },
            xing: {
                type: "boolean",
                default: true
            }
        },
        getEditWrapperProps({
            container
        }) {
            if ('cwp-full-width-wide-container' === container || 'cwp-full-width-small-container' === container || 'cwp-same-width-full-container' === container) {
                return {
                    'data-align': 'full'
                };
            } else if ('cwp-same-width-wide-container' === container) {
                return {
                    'data-align': 'wide'
                };
            }
        },
        edit: function(props) {
            var attributes = props.attributes;
            
			// override default params for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{
				attributes.paddingBeforeIntro = -1;
				attributes.paddingAfterIntro = -1;
				attributes.paddingAfterItems = -1;
				attributes.boxradius = -1;
				attributes.boxradiusfix = true;
				attributes.boxpadding = -1;
				attributes.boxpaddingfix = true;
				attributes.container = 'cwp-full-width-small-container';
			}
			
			// disable introsection for new entries only
			if(attributes.introsection === 'empty' || attributes.introsection === undefined)
			{				
				if(
					(attributes.introtitle !== '' && attributes.introtitle !== undefined) ||
					(attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ||
					(attributes.introduction !== '' && attributes.introduction !== undefined))
				{
					attributes.introsection = 'enabled';
				} else {
					attributes.introsection = 'disabled';
				}
			}

			var solidColorPreset = el(ColorPalette, {
				value: attributes.solidColor,
				onChange: function(e) {
					props.setAttributes({
						solidColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#00d1b2",
					name: "teal"
				}, {
					color: "#3373dc",
					name: "royal blue"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var backgroundTextColorPreset = el(ColorPalette, {
				value: attributes.backgroundTextColor,
				onChange: function(e) {
					props.setAttributes({
						backgroundTextColor: e
					});
				},
				colors: [{
					color: "#ffffff",
					name: "white"
				}, {
					color: "#333333",
					name: "dark"
				}, {
					color: "#000000",
					name: "black"
				}, {
					color: "#209cef",
					name: "sky blue"
				}, {
					color: "#22d25f",
					name: "green"
				}]
			});
			var gradientPreset = el(SelectControl, {
				label: __('Gradients', 'cosmic-blocks'),
				options: gradient_options.map(function(e) {
					return {
						value: e.colors,
						label: e.name
					};
				}),
				value: attributes.gradient,
				onChange: function(e) {
					props.setAttributes({
						gradient: e
					});
				}
			});
			var back_style = function() {
				var s = {};
				if (attributes.backgroundType === 'color' && attributes.solidColor !== '' && attributes.solidColor !== undefined) {
					s = {
						background: attributes.solidColor
					};
				} else if (attributes.backgroundType === 'gradient' && attributes.gradient !== '' && attributes.gradient !== undefined) {
					s = {
						background: "linear-gradient(to bottom, " + attributes.gradient + ")"
					};
				} else if (attributes.backgroundType === 'image' && attributes.backgroundMediaURL !== '' && attributes.backgroundMediaURL !== undefined) {
					s = {
						background: "url( " + attributes.backgroundMediaURL + " )",
						backgroundSize: "cover",
						backgroundPosition: "center"
					};
				}
				return s;
			};
			var back_text_style = function() {
				var s = {};
				if (attributes.backgroundTextColor !== '' && attributes.backgroundTextColor !== undefined) {
					s = {
						color: attributes.backgroundTextColor
					};
				}
				return s;
			};
			var box_padding = function() {
				var s = {};
				if (attributes.paddingBeforeIntro >= 0) {
					s.paddingTop = attributes.paddingBeforeIntro;
				}
				if (attributes.paddingAfterItems >= 0) {
					s.paddingBottom = attributes.paddingAfterItems;
				}
				return s;
			};
			
            return [
                el(
                    Fragment,
                    null,
					el(InspectorControls, {
                            key: 'inspector'
                        }, // Display the block options in the inspector panel.
						el(wp.components.PanelBody, {
								title: __('Intro', 'cosmic-blocks'),
								className: 'cwp-inspector-intro',
								initialOpen: false
							},
							el(SelectControl, {
								label: __('Enable/disable', 'cosmic-blocks'),
								value: attributes.introsection,
								options: [{
										label: __('Disabled', 'cosmic-blocks'),
										value: 'disabled'
									},
									{
										label: __('Enabled', 'cosmic-blocks'),
										value: 'enabled'
									}
								],
								onChange: function onChange(value) {
									props.setAttributes({
										introsection: value
									});
								}
							}),
							attributes.introsection === 'enabled' ? el('p', {}, __('Intro text color', 'cosmic-blocks')) : '',
							attributes.introsection === 'enabled' ? backgroundTextColorPreset : '',
							attributes.introsection === 'enabled' ? el(RangeControl, {
								label: __('Padding after intro text', 'cosmic-blocks'),
								value: attributes.paddingAfterIntro,
								allowReset: false,
								initialPosition: 50,
								onChange: function(e) {
									return props.setAttributes({
										paddingAfterIntro: e
									});
								},
								min: -1,
								max: 200
							}) : '',
						),
                        el(wp.components.PanelBody, {
                                title: __('Layout', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: false
							},
                            el(SelectControl, {
                                label: __('Container width', 'cosmic-blocks'),
                                value: attributes.container,
                                options: container_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    props.setAttributes({
                                        container: e
                                    });
                                }
                            }),
                            el(RangeControl, {
                                label: __('Padding top', 'cosmic-blocks'),
                                value: attributes.paddingBeforeIntro,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingBeforeIntro: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el(RangeControl, {
                                label: __('Padding bottom', 'cosmic-blocks'),
                                value: attributes.paddingAfterItems,
                                allowReset: false,
                                initialPosition: 50,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        paddingAfterItems: e
                                    });
                                },
                                min: -1,
                                max: 200
                            }),
                            el('p', {
                                className: 'cwp-custom-label'
                            }, __('Background', 'cosmic-blocks')),
                            el(ButtonGroup, {},
                                backgroundType.map(function(e) {
                                    return el(Button, {
                                        key: e.label,
                                        isLarge: !0,
                                        isPrimary: attributes.backgroundType === e.value,
                                        "aria-pressed": attributes.backgroundType === e.value,
                                        onClick: function() {
                                            return props.setAttributes({
                                                backgroundType: e.value
                                            });
                                        }
                                    }, e.label);
                                })
                            ),
                            "color" === attributes.backgroundType && solidColorPreset,
                            "gradient" === attributes.backgroundType && gradientPreset,
                            "image" === attributes.backgroundType && el(
                                MediaUpload, {
                                    key: "mediaupload",
                                    onSelect: function(media) {
                                        return props.setAttributes({
                                            backgroundMediaURL: media.url,
                                            backgroundMediaID: media.id
                                        });
                                    },
                                    type: "image",
                                    value: attributes.backgroundMediaID,
                                    render: function(e) {
                                        var r = e.open;
                                        return el(Fragment, null, el(Button, {
                                            className: "button-link cwp-custom-button",
                                            onClick: r
                                        }, attributes.backgroundMediaID ? el("img", {
                                            src: attributes.backgroundMediaURL
                                        }) : __('Set background image', 'cosmic-blocks')));
                                    }
                                }
                            ),
                            "image" === attributes.backgroundType && attributes.backgroundMediaID && el(Fragment, null, el("p", {
                                className: "cwp-custom-edit-image"
                            }, __('Click the image to edit or update', 'cosmic-blocks')), el(Button, {
                                className: "button-link",
                                style: {
                                    marginBottom: "20px"
                                },
                                onClick: function() {
                                    return props.setAttributes({
                                        backgroundMediaURL: void 0,
                                        backgroundMediaID: void 0
                                    });
                                }
                            }, __('Remove background image', 'cosmic-blocks'))),
                            el(TextControl, {
                                label: __('Block ID', 'cosmic-blocks'),
                                value: attributes.blockID,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        blockID: e
                                    });
                                }
                            }),
						),
						el(wp.components.PanelBody, {
                                title: __('Items', 'cosmic-blocks'),
                                className: 'cwp-inspector-layout',
                                initialOpen: true
                            },
							el(SelectControl, {
								label: __('Position', 'cosmic-blocks'),
								value: attributes.positionClass,
								options: [{
										label: __('Left', 'cosmic-blocks'),
										value: 'cwp-all-left'
									},
									{
										label: __('Center', 'cosmic-blocks'),
										value: 'cwp-all-center'
									},
									{
										label: __('Right', 'cosmic-blocks'),
										value: 'cwp-all-right'
									},
									{
										label: __('Grid 2', 'cosmic-blocks'),
										value: 'cwp-all-grid-2'
									},
									{
										label: __('Grid 3', 'cosmic-blocks'),
										value: 'cwp-all-grid-3'
									},
									{
										label: __('Grid 4', 'cosmic-blocks'),
										value: 'cwp-all-grid-4'
									},
									{
										label: __('Grid 5', 'cosmic-blocks'),
										value: 'cwp-all-grid-5'
									}
								],
								onChange: function onChange(value) {
									props.setAttributes({
                                        positionClass: value
                                    });
								}
							}),
							el(SelectControl, {
								label: __('Button style', 'cosmic-blocks'),
								value: attributes.buttonStyle,
								options: button_options.map(function(e) {
									return {
										value: e.value,
										label: e.label
									};
								}),
								onChange: function onChange(value) {
									props.setAttributes({
										buttonStyle: value
									});
								}
							}),
							el(SelectControl, {
								label: __('Button type', 'cosmic-blocks'),
								value: attributes.buttonType,
								options: [{
									label: __('Text & Icon'),
									value: 'text_icon'
								}, {
									label: __('Text'),
									value: 'text'
								}, {
									label: __('Icon'),
									value: 'icon'
								}],
								onChange: function onChange(value) {
									props.setAttributes({
										buttonType: value
									});
								}
							}),
							el('p', {}, __('Show or hide items', 'cosmic-blocks')),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: "Facebook",
									checked: attributes.facebook,
									onChange: function(e) {
										return props.setAttributes({
											facebook: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
									},
								el(CheckboxControl, {
									label: "Twitter",
									checked: attributes.twitter,
									onChange: function(e) {
										return props.setAttributes({
											twitter: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: "Linkedin",
									checked: attributes.linkedin,
									onChange: function(e) {
										return props.setAttributes({
											linkedin: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: "Whatsapp",
									checked: attributes.whatsapp,
									onChange: function(e) {
										return props.setAttributes({
											whatsapp: e
										});
									}
								}),
							),
							el('div', {
									className: 'cwp-control'
								},
								el(CheckboxControl, {
									label: "Xing",
									checked: attributes.xing,
									isChecked: true,
									onChange: function(e) {
										return props.setAttributes({
											xing: e
										});
									}
								})
							)
                        ),
						el(wp.components.PanelBody, {
                                title: __('Animation', 'cosmic-blocks'),
                                className: 'cwp-inspector-animation',
                                initialOpen: false
                            },
                            el(SelectControl, {
								label: __('Animation', 'cosmic-blocks'),
                                value: attributes.animationStyle,
                                options: animation_options.map(function(e) {
                                    return {
                                        value: e.value,
                                        label: e.label
                                    };
                                }),
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationStyle: e
                                    });
                                }
                            }),
                            el(TextControl, {
								label: __('Animation Delay', 'cosmic-blocks'),
                                value: attributes.animationDelay,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        animationDelay: e
                                    });
                                },
                                help: __('Enter in milliseconds', 'cosmic-blocks')
                            }),
                            el(RangeControl, {
                                beforeIcon: 'arrow-left-alt2',
                                afterIcon: 'arrow-right-alt2',
                                label: __('Threshold', 'cosmic-blocks'),
                                value: attributes.threshold,
								allowReset: false,
								initialPosition: 40,
                                onChange: function(e) {
                                    return props.setAttributes({
                                        threshold: e
                                    });
                                },
                                min: 0,
                                max: 100
                            }),
						)
                    ),
					el('div', {
							id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-backend-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
							style: back_style()
                        },
						el('div', {
                                className: 'cwp-common-main-wrap-inner' + (attributes.animationStyle !== '' && attributes.animationStyle !== undefined ? ' animated ' + attributes.animationStyle : ''),
								style: box_padding()
                            },
							attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
									style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'h3',
                                            placeholder: __('Title', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introtitle,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-subtitle'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Subtitle', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introsubtitle,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introsubtitle: e
                                                });
                                            }
                                        }),
                                    ),
                                ),
                                el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(RichText, {
                                            tagName: 'p',
                                            placeholder: __('Introduction', 'cosmic-blocks'),
                                            keepPlaceholderOnFocus: true,
                                            value: attributes.introduction,
											style: back_text_style(),
                                            isSelected: attributes.isSelected,
											formattingControls: [ 'bold', 'italic', 'strikethrough', 'link' ],
                                            onChange: function onChange(e) {
                                                return props.setAttributes({
                                                    introduction: e
                                                });
                                            }
                                        }),
                                    ),
                                )
                            ) : '',
                            el('div', {
                                    className: 'cwp-main-wrapper cwp-' + attributes.columns + '-column'
                                },
								el('div', {
										className: 'cwp-inner-wrap'
									},
									el('div', {
											className: 'cwp-server-side-render'
										},
										el(ServerSideRender, {
											block: "cwp/social-share",
											attributes: {
												preview: true,
												blockID: attributes.blockID,
												columns: attributes.columns,
												buttonStyle: attributes.buttonStyle,
												buttonType: attributes.buttonType,
												positionClass: attributes.positionClass,
												container: attributes.container,
												backgroundType: attributes.backgroundType,
												backgroundTextColor: attributes.backgroundTextColor,
												solidColor: attributes.solidColor,
												gradient: attributes.gradient,
												backgroundMediaID: attributes.backgroundMediaID,
												backgroundMediaURL: attributes.backgroundMediaURL,
												animationStyle: attributes.animationStyle,
												animationDelay: attributes.animationDelay,
												threshold: attributes.threshold,
												paddingBeforeIntro: attributes.paddingBeforeIntro,
												paddingAfterIntro: attributes.paddingAfterIntro,
												paddingAfterItems: attributes.paddingAfterItems,
												introsection: attributes.introsection,
												introtitle: attributes.introtitle,
												introsubtitle: attributes.introsubtitle,
												introduction: attributes.introduction,
												boxradius: attributes.boxradius,
												boxradiusfix: attributes.boxradiusfix,
												boxpadding: attributes.boxpadding,
												boxpaddingfix: attributes.boxpaddingfix,
												facebook: attributes.facebook,
												twitter: attributes.twitter,
												linkedin: attributes.linkedin,
												whatsapp: attributes.whatsapp,
												xing: attributes.xing
											}
										})
									)
								)
                            )
                        )
                    ),

                    /** Front view **/
					el('div', {
                            id: (attributes.blockID !== '' && attributes.blockID !== undefined ? attributes.blockID : ''),
                            className: props.className + ' ' + attributes.container + ' cwp-common-main-wrap cwp-front-view-content' + (Object.keys(back_style()).length !== 0 ? ' cwp-common-main-wrap-has-background' : ''),
                            style: back_style()
                        },
                        el('div', {
                                className: 'cwp-common-main-wrap-inner',
                                style: box_padding(),
                                "data-scroll-class": attributes.animationStyle,
                                "data-scroll-delay": attributes.animationDelay,
                                "data-scroll-threshold": attributes.threshold
                            },
                            attributes.introsection === 'enabled' ? el('div', {
                                    className: 'cwp-main-intro',
                                    style: attributes.paddingAfterIntro >= 0 ? {
										paddingBottom: attributes.paddingAfterIntro
									} : {}
                                },
                                (attributes.introtitle !== '' && attributes.introtitle !== undefined) || (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el('div', {
                                        className: 'cwp-intro-title'
                                    },
                                    el('h3', {
                                            style: back_text_style()
                                        },
                                        (attributes.introtitle !== '' && attributes.introtitle !== undefined) ? el(
                                            RichText.Content, {
                                                tagName: '',
                                                value: attributes.introtitle
                                            }
                                        ) : '',
                                        (attributes.introsubtitle !== '' && attributes.introsubtitle !== undefined) ? el(
                                            RichText.Content, {
                                                tagName: 'span',
                                                value: attributes.introsubtitle
                                            }
                                        ) : '',
                                    ),
                                ) : '',
                                (attributes.introduction !== '' && attributes.introduction !== undefined) ? el('div', {
                                        className: 'cwp-intro-introduction'
                                    },
                                    el('div', {
                                            className: 'cwp-intro-input'
                                        },
                                        el(
                                            RichText.Content, {
                                                tagName: 'p',
                                                value: attributes.introduction,
                                                style: back_text_style()
                                            }
                                        ),
                                    ),
                                ) : '',
                            ) : '',
							el(ServerSideRender, {
								block: "cwp/social-share",
								attributes: {
									preview: true,
									blockID: attributes.blockID,
									columns: attributes.columns,
									buttonStyle: attributes.buttonStyle,
									buttonType: attributes.buttonType,
									positionClass: attributes.positionClass,
									container: attributes.container,
									backgroundType: attributes.backgroundType,
									backgroundTextColor: attributes.backgroundTextColor,
									solidColor: attributes.solidColor,
									gradient: attributes.gradient,
									backgroundMediaID: attributes.backgroundMediaID,
									backgroundMediaURL: attributes.backgroundMediaURL,
									animationStyle: attributes.animationStyle,
									animationDelay: attributes.animationDelay,
									threshold: attributes.threshold,
									paddingBeforeIntro: attributes.paddingBeforeIntro,
									paddingAfterIntro: attributes.paddingAfterIntro,
									paddingAfterItems: attributes.paddingAfterItems,
									introsection: attributes.introsection,
									introtitle: attributes.introtitle,
									introsubtitle: attributes.introsubtitle,
									introduction: attributes.introduction,
									boxradius: attributes.boxradius,
									boxradiusfix: attributes.boxradiusfix,
									boxpadding: attributes.boxpadding,
									boxpaddingfix: attributes.boxpaddingfix,
									facebook: attributes.facebook,
									twitter: attributes.twitter,
									linkedin: attributes.linkedin,
									whatsapp: attributes.whatsapp,
									xing: attributes.xing
								}
							})
                        )
                    )
                    /** Front view **/
                )
            ];
        },
        save: function() {
			// Rendering in PHP
			return null;
        }
    });
})(
    window.wp
);